==> haskell-path-io-1.3.3-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-A1YC0HmEABP68CD3oEVMgB
key: path-io-1.3.3-A1YC0HmEABP68CD3oEVMgB
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: d630e4ec56f00c72d7aa410e9b9f3e64
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-A1YC0HmEABP68CD3oEVMgB
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq filepath-1.4.1.2
    path-0.6.1-AA7hd1693WNHbdVd23hy0J
    temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2 time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=b98e175ed6b9bea3c0e69ce59165f686
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=eff2744d823431f8209ca0d87f216828
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             path-0.6.1-AA7hd1693WNHbdVd23hy0J=cb35d7bc7975f27a0b56d5838d2e7ad1
             temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2=b86cfc09a1f585d90dca5d21791f6633
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.3.3-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.3.3
id: path-io-1.3.3-ARPDNoeKnFGBwafxYIgcOB
key: path-io-1.3.3-ARPDNoeKnFGBwafxYIgcOB
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Path.IO
abi: a94c39b7359c90128e3592e14660b9de
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-io-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/path-io-1.3.3
hs-libraries: HSpath-io-1.3.3-ARPDNoeKnFGBwafxYIgcOB
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq filepath-1.4.1.2
    path-0.6.1-HxWEBXlLqpiFMz7tIfUpvq
    temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2 time-1.8.0.2
    transformers-0.5.2.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=b98e175ed6b9bea3c0e69ce59165f686
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=eff2744d823431f8209ca0d87f216828
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             path-0.6.1-HxWEBXlLqpiFMz7tIfUpvq=97f8f87b62109afd4b3bd6522066bef1
             temporary-1.2.1.1-C4Oi7my6bSWB1kyblmdgo2=b86cfc09a1f585d90dca5d21791f6633
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
